@@ -9,6 +9,7 @@ import typing as t
 import pytest
 
 import libtmux
+from libtmux import exc
 from libtmux._compat import LooseVersion
 from libtmux.common import (
     TMUX_MAX_VERSION,
@@ -24,7 +25,6 @@ from libtmux.common import (
     session_check_name,
     tmux_cmd,
 )
-from libtmux.exc import BadSessionName, LibTmuxException, TmuxCommandNotFound
 
 if t.TYPE_CHECKING:
     from libtmux.session import Session
@@ -40,7 +40,7 @@ def test_has_version() -> None:
 def test_tmux_cmd_raises_on_not_found(monkeypatch: pytest.MonkeyPatch) -> None:
     """Verify raises if tmux command not found."""
     monkeypatch.setenv("PATH", "")
-    with pytest.raises(TmuxCommandNotFound):
+    with pytest.raises(exc.TmuxCommandNotFound):
         tmux_cmd("-V")
 
 
@@ -111,7 +111,7 @@ def test_session_check_name(
 ) -> None:
     """Verify session_check_name()."""
     if raises:
-        with pytest.raises(BadSessionName) as exc_info:
+        with pytest.raises(exc.BadSessionName) as exc_info:
             session_check_name(session_name)
         if exc_msg_regex is not None:
             assert exc_info.match(exc_msg_regex)
@@ -321,7 +321,7 @@ VERSION_PARSING_FIXTURES: list[VersionParsingFixture] = [
         mock_platform=None,
         expected_version=None,
         raises=True,
-        exc_msg_regex="is running tmux 1.3 or earlier",
+        exc_msg_regex="does not meet the minimum tmux version requirement",
     ),
 ]
 
@@ -355,7 +355,7 @@ def test_version_parsing(
         monkeypatch.setattr(sys, "platform", mock_platform)
 
     if raises:
-        with pytest.raises(LibTmuxException) as exc_info:
+        with pytest.raises(exc.LibTmuxException) as exc_info:
             get_version()
         if exc_msg_regex is not None:
             exc_info.match(exc_msg_regex)
@@ -499,7 +499,7 @@ def test_version_validation(
 
     if check_type == "min_version":
         if raises:
-            with pytest.raises(LibTmuxException) as exc_info:
+            with pytest.raises(exc.LibTmuxException) as exc_info:
                 has_minimum_version()
             if exc_msg_regex is not None:
                 exc_info.match(exc_msg_regex)
@@ -508,134 +508,3 @@ def test_version_validation(
     elif check_type == "type_check":
         assert mock_version is not None  # For type checker
         assert isinstance(has_version(mock_version), bool)
-
-
-class VersionDeprecationFixture(t.NamedTuple):
-    """Test fixture for version deprecation warning."""
-
-    test_id: str
-    version: str
-    suppress_env: bool
-    expected_warning: bool
-
-
-VERSION_DEPRECATION_FIXTURES: list[VersionDeprecationFixture] = [
-    VersionDeprecationFixture(
-        test_id="deprecated_version_warns",
-        version="3.1",
-        suppress_env=False,
-        expected_warning=True,
-    ),
-    VersionDeprecationFixture(
-        test_id="old_deprecated_version_warns",
-        version="2.9",
-        suppress_env=False,
-        expected_warning=True,
-    ),
-    VersionDeprecationFixture(
-        test_id="current_version_no_warning",
-        version="3.2a",
-        suppress_env=False,
-        expected_warning=False,
-    ),
-    VersionDeprecationFixture(
-        test_id="newer_version_no_warning",
-        version="3.5",
-        suppress_env=False,
-        expected_warning=False,
-    ),
-    VersionDeprecationFixture(
-        test_id="env_var_suppresses_warning",
-        version="3.0",
-        suppress_env=True,
-        expected_warning=False,
-    ),
-]
-
-
-@pytest.mark.parametrize(
-    list(VersionDeprecationFixture._fields),
-    VERSION_DEPRECATION_FIXTURES,
-    ids=[test.test_id for test in VERSION_DEPRECATION_FIXTURES],
-)
-def test_version_deprecation_warning(
-    test_id: str,
-    version: str,
-    suppress_env: bool,
-    expected_warning: bool,
-    monkeypatch: pytest.MonkeyPatch,
-) -> None:
-    """Test version deprecation warning behavior."""
-    import warnings
-
-    import libtmux.common
-
-    # Reset the warning flag for each test
-    monkeypatch.setattr(libtmux.common, "_version_deprecation_checked", False)
-
-    # Set or clear the suppress env var
-    if suppress_env:
-        monkeypatch.setenv("LIBTMUX_SUPPRESS_VERSION_WARNING", "1")
-    else:
-        monkeypatch.delenv("LIBTMUX_SUPPRESS_VERSION_WARNING", raising=False)
-
-    with warnings.catch_warnings(record=True) as w:
-        warnings.simplefilter("always")
-        libtmux.common._check_deprecated_version(LooseVersion(version))
-
-    if expected_warning:
-        assert len(w) == 1
-        assert issubclass(w[0].category, FutureWarning)
-        assert version in str(w[0].message)
-        assert "3.2a" in str(w[0].message)
-    else:
-        assert len(w) == 0
-
-
-def test_version_deprecation_warns_once(monkeypatch: pytest.MonkeyPatch) -> None:
-    """Test that deprecation warning only fires once per process."""
-    import warnings
-
-    import libtmux.common
-
-    monkeypatch.setattr(libtmux.common, "_version_deprecation_checked", False)
-    monkeypatch.delenv("LIBTMUX_SUPPRESS_VERSION_WARNING", raising=False)
-
-    with warnings.catch_warnings(record=True) as w:
-        warnings.simplefilter("always")
-        libtmux.common._check_deprecated_version(LooseVersion("3.1"))
-        libtmux.common._check_deprecated_version(LooseVersion("3.1"))
-
-    assert len(w) == 1
-
-
-def test_version_deprecation_via_get_version(monkeypatch: pytest.MonkeyPatch) -> None:
-    """Test deprecation warning fires through get_version() call.
-
-    This integration test verifies the warning is emitted when calling
-    get_version() with an old tmux version, testing the full call chain.
-    """
-    import warnings
-
-    import libtmux.common
-
-    class MockTmuxOutput:
-        stdout: t.ClassVar = ["tmux 3.1"]
-        stderr: t.ClassVar[list[str]] = []
-
-    def mock_tmux_cmd(*args: t.Any, **kwargs: t.Any) -> MockTmuxOutput:
-        return MockTmuxOutput()
-
-    monkeypatch.setattr(libtmux.common, "_version_deprecation_checked", False)
-    monkeypatch.setattr(libtmux.common, "tmux_cmd", mock_tmux_cmd)
-    monkeypatch.delenv("LIBTMUX_SUPPRESS_VERSION_WARNING", raising=False)
-
-    with warnings.catch_warnings(record=True) as w:
-        warnings.simplefilter("always")
-        version = libtmux.common.get_version()
-
-    assert str(version) == "3.1"
-    assert len(w) == 1
-    assert issubclass(w[0].category, FutureWarning)
-    assert "3.1" in str(w[0].message)
-    assert "3.2a" in str(w[0].message)
